<?php

namespace Drupal\content_snapshot\Compiler;

use Drupal\content_snapshot\Encoder\YamlEncoder;
use Drupal\content_snapshot\Encoder\YamlEncoderD9;
use Drupal\content_snapshot\Logger\Logger;
use Drupal\content_snapshot\Logger\LoggerD9;
use Symfony\Component\DependencyInjection\Compiler\CompilerPassInterface;
use Symfony\Component\DependencyInjection\ContainerBuilder;

/**
 * Modifies container to provide D9 compatibility.
 */
class D9CompatibilityExtensionPass implements CompilerPassInterface {

  /**
   * {@inheritdoc}
   *
   * @throws \Exception
   */
  public function process(ContainerBuilder $container) {

    if ($container->hasDefinition('content_snapshot.encoder.yaml')) {
      $definition = $container->getDefinition('content_snapshot.encoder.yaml');
      if ($definition->getClass() === YamlEncoder::class) {
        $definition->setClass(YamlEncoderD9::class);
      }
    }

    if ($container->hasDefinition('content_snapshot.logger')) {
      $definition = $container->getDefinition('content_snapshot.logger');
      if ($definition->getClass() === Logger::class) {
        $definition->setClass(LoggerD9::class);
      }
    }
  }

}
