<?php

namespace Drupal\content_snapshot\ContentLoader;

use Drupal\content_snapshot\Snapshot\SnapshotItemInterface;

/**
 * Class for ContentLoaderChain.
 */
class ContentLoaderChain implements ContentLoaderInterface {

  /**
   * Array of chained content loaders.
   *
   * @var \Drupal\content_snapshot\ContentLoader\ContentLoaderInterface[]
   */
  private $contentLoaders = [];

  /**
   * Add content reader to the chain of loaders.
   *
   * @param \Drupal\content_snapshot\ContentLoader\ContentLoaderInterface $contentLoader
   *   Content Reader.
   */
  public function addContentLoader(ContentLoaderInterface $contentLoader) {
    $this->contentLoaders[] = $contentLoader;
  }

  /**
   * {@inheritDoc}
   */
  public function load(SnapshotItemInterface $snapshotItem) {
    foreach ($this->contentLoaders as $contentLoader) {
      if ($object = $contentLoader->load($snapshotItem)) {
        return $object;
      }
    }

    return NULL;
  }

}
